"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _BootstrapProvider = _interopRequireDefault(require("@bootstrap-styled/provider/lib/BootstrapProvider"));

var _ComponentsListRenderer = _interopRequireWildcard(require("../ComponentsListRenderer"));

/**
 * Testing our ComponentsListRenderer component
 */
describe('<ComponentsListRenderer />', function () {
  var theme = _ComponentsListRenderer.defaultProps.theme;
  var props;
  beforeEach(function () {
    props = Object.assign(_ComponentsListRenderer.defaultProps, {
      items: [{
        visibleName: 'First component',
        href: '/#first-component',
        filepath: 'first-component.md',
        heading: false,
        level: 0,
        content: false,
        collapse: true,
        slug: 'first-component',
        components: [],
        sections: []
      }],
      isOpenCollapse: false
    });
  });
  it('should render an ComponentListRenderer with theme', function () {
    var renderedComponent = (0, _enzyme.mount)(_react.default.createElement(_BootstrapProvider.default, {
      theme: theme,
      injectGlobal: false
    }, _react.default.createElement(_ComponentsListRenderer.default, props)));
    expect(renderedComponent.find('ComponentsListRendererUnstyled').length).toEqual(1);
  });
  it('should render a ComponentsListRenderer with items', function () {
    var renderedComponent = (0, _enzyme.mount)(_react.default.createElement(_BootstrapProvider.default, {
      theme: theme,
      injectGlobal: false
    }, _react.default.createElement(_ComponentsListRenderer.default, props)));
    expect(renderedComponent.find('ComponentsListRendererUnstyled').props().items).toEqual([{
      collapse: true,
      components: [],
      content: false,
      filepath: 'first-component.md',
      heading: false,
      href: '/#first-component',
      level: 0,
      visibleName: 'First component',
      sections: [],
      slug: 'first-component'
    }]);
  });
  it('should render an ComponentsListRenderer without collapse', function () {
    var newProps = {
      theme: theme,
      items: [{
        visibleName: 'First component',
        href: '/#first-component',
        filepath: 'first-component.md',
        heading: true,
        level: 0,
        content: false,
        collapse: false,
        slug: 'first-component',
        components: [],
        sections: [{
          visibleName: 'Sub component',
          href: '/#sub-component',
          filepath: 'sub-component.md',
          heading: false,
          level: 0,
          content: false,
          collapse: false,
          slug: 'sub-component',
          components: [],
          sections: []
        }]
      }]
    };
    var renderedComponent = (0, _enzyme.mount)(_react.default.createElement(_BootstrapProvider.default, {
      theme: theme,
      injectGlobal: false
    }, _react.default.createElement(_ComponentsListRenderer.default, newProps)));
    expect(renderedComponent.contains('Collapse')).toBe(false);
  });
  it('should not render any children', function () {
    var newProps = {
      theme: theme,
      items: []
    };
    var renderedComponent = (0, _enzyme.mount)(_react.default.createElement(_BootstrapProvider.default, {
      theme: theme,
      injectGlobal: false
    }, _react.default.createElement(_ComponentsListRenderer.default, newProps)));
    expect(renderedComponent.find('ComponentsListRendererUnstyled').props().children).toBe(undefined);
  });
});