"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getMarkdown = getMarkdown;
exports.default = JsDoc;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _lodash = _interopRequireDefault(require("lodash.map"));

var _Markdown = _interopRequireDefault(require("../Markdown"));

var plural = function plural(array, caption) {
  return array.length === 1 ? caption : "".concat(caption, "s");
};

var list = function list(array) {
  return array.map(function (item) {
    return item.description;
  }).join(', ');
};

var paragraphs = function paragraphs(array) {
  return array.map(function (item) {
    return item.description;
  }).join('\n\n');
};

var fields = {
  deprecated: function deprecated(value) {
    return "**Deprecated:** ".concat(value[0].description);
  },
  see: function see(value) {
    return paragraphs(value);
  },
  link: function link(value) {
    return paragraphs(value);
  },
  author: function author(value) {
    return "".concat(plural(value, 'Author'), ": ").concat(list(value));
  },
  version: function version(value) {
    return "Version: ".concat(value[0].description);
  },
  since: function since(value) {
    return "Since: ".concat(value[0].description);
  }
};

function getMarkdown(props) {
  return (0, _lodash.default)(fields, function (format, field) {
    return props[field] && format(props[field]);
  }).filter(Boolean).join('\n\n');
}

function JsDoc(props) {
  var markdown = getMarkdown(props);
  return markdown ? _react.default.createElement(_Markdown.default, {
    text: markdown
  }) : null;
}
/* eslint-disable react/require-default-props, react/no-unused-prop-types */


JsDoc.propTypes = {
  deprecated: _propTypes.default.array,
  see: _propTypes.default.array,
  link: _propTypes.default.array,
  author: _propTypes.default.array,
  version: _propTypes.default.array,
  since: _propTypes.default.array
};
/* eslint-enable react/require-default-props, react/no-unused-prop-types */