"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.propTypes = exports.defaultProps = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _lodash = _interopRequireDefault(require("lodash.omit"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _lib = _interopRequireDefault(require("map-to-css-modules/lib"));

var _classnames = _interopRequireDefault(require("classnames"));

var _Strong = _interopRequireDefault(require("@bootstrap-styled/v4/lib/Strong"));

var defaultProps = {
  size: 'inherit',
  color: 'base',
  underlined: false,
  theme: {
    styleguide: {
      '$rsg-text-font-size': {
        inherit: 'inherit',
        sm: '0.8em',
        base: '1em',
        text: '1.2em'
      },
      '$rsg-text-color': '#333',
      '$rsg-text-color-light': '#555556',
      '$rsg-text-border-bottom': '1px dotted #CCCCCC',
      '$rsg-text-font-family': '-apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif'
    }
  }
};
/* eslint-disable react/require-default-props */

exports.defaultProps = defaultProps;
var propTypes = {
  /**
   * @ignore
   */
  className: _propTypes.default.string,
  // eslint-disable-line react/require-default-props

  /** Tags used for semantic. Can be: */
  semantic: _propTypes.default.oneOf(['em', 'strong']),
  // eslint-disable-line react/require-default-props

  /** Semantic sizes. Can be: */
  size: _propTypes.default.oneOf(['inherit', 'small', 'base', 'text']),

  /** Semantic colors. Can be: */
  color: _propTypes.default.oneOf(['base', 'light']),

  /** Toggle underlined style. */
  underlined: _propTypes.default.bool,

  /** Specified node element will be passed as children of `<TextRenderer />` component. */
  children: _propTypes.default.node.isRequired,

  /** Theme variables. Can be: */
  theme: _propTypes.default.shape({
    styleguide: _propTypes.default.shape({
      '$rsg-text-font-size': _propTypes.default.object,
      '$rsg-text-color': _propTypes.default.string,
      '$rsg-text-color-light': _propTypes.default.string,
      '$rsg-text-border-bottom': _propTypes.default.string,
      '$rsg-text-font-family': _propTypes.default.string
    })
  }),

  /**
   * Replace or remove a className from the component.
   * See example <a href="https://www.npmjs.com/package/map-to-css-modules" target="_blank">here</a>.
   */
  cssModule: _propTypes.default.object // eslint-disable-line react/require-default-props

};
/* eslint-enable react/require-default-props */

exports.propTypes = propTypes;

var TextRendererUnstyled = function TextRendererUnstyled(props) {
  var _cn;

  var _omit = (0, _lodash.default)(props, ['theme']),
      className = _omit.className,
      children = _omit.children,
      semantic = _omit.semantic,
      size = _omit.size,
      color = _omit.color,
      underlined = _omit.underlined,
      cssModule = _omit.cssModule,
      attributes = (0, _objectWithoutProperties2.default)(_omit, ["className", "children", "semantic", "size", "color", "underlined", "cssModule"]);

  var Tag = semantic && semantic === 'strong' ? _Strong.default : semantic === 'em' ? 'em' : 'span'; // eslint-disable-line no-nested-ternary

  return _react.default.createElement(Tag, (0, _extends2.default)({
    className: (0, _lib.default)((0, _classnames.default)(className, (_cn = {}, (0, _defineProperty2.default)(_cn, "size-".concat(size), !!size), (0, _defineProperty2.default)(_cn, "color-".concat(color), !!color), (0, _defineProperty2.default)(_cn, "underlined", !!underlined), _cn), 'rsg-text'), cssModule)
  }, attributes), children);
};

TextRendererUnstyled.defaultProps = defaultProps;
TextRendererUnstyled.propTypes = propTypes;
var TextRenderer = (0, _styledComponents.default)(TextRendererUnstyled).withConfig({
  displayName: "TextRenderer",
  componentId: "sc-1hcjghd-0"
})(["  ", ""], function (props) {
  return "\n    &.rsg-text {\n      font-family: ".concat(props.theme.styleguide['$rsg-text-font-family'], ";\n    }\n    &.rsg-text.size-inherit {\n      font-size: ").concat(props.theme.styleguide['$rsg-text-font-size'].inherit, ";\n    }\n    &.rsg-text.size-small {\n      font-size: ").concat(props.theme.styleguide['$rsg-text-font-size'].sm, ";\n    }\n    &.rsg-text.size-base {\n      font-size: ").concat(props.theme.styleguide['$rsg-text-font-size'].base, ";\n    }\n    &.rsg-text.size-text {\n      font-size: ").concat(props.theme.styleguide['$rsg-text-font-size'].text, ";\n    }\n    &.rsg-text.underlined {\n      border-bottom: ").concat(props.theme.styleguide['$rsg-text-border-bottom'], ";\n    }\n    &.rsg-text.color-base {\n      color: ").concat(props.theme.styleguide['$rsg-text-color'], ";\n    }\n    &.rsg-text.color-light {\n      color: ").concat(props.theme.styleguide['$rsg-text-color-light'], ";\n    }\n ");
});
TextRenderer.defaultProps = defaultProps;
TextRenderer.propTypes = propTypes;
/** @component */

var _default = TextRenderer;
exports.default = _default;