"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _enzyme = require("enzyme");

var _react = _interopRequireDefault(require("react"));

var _BootstrapProvider = _interopRequireDefault(require("@bootstrap-styled/provider/lib/BootstrapProvider"));

var _TextRenderer = _interopRequireWildcard(require("../TextRenderer"));

/* eslint-disable */

/**
 * Testing our TextRenderer component
 */
var theme = _TextRenderer.defaultProps.theme;

var children = _react.default.createElement("h1", null, "Test");

var renderComponent = function renderComponent() {
  var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  return (0, _enzyme.shallow)(_react.default.createElement(_TextRenderer.default, props, children));
};

var renderComponentUsingTheme = function renderComponentUsingTheme(props) {
  return (0, _enzyme.mount)(_react.default.createElement(_BootstrapProvider.default, {
    theme: theme,
    injectGlobal: false
  }, _react.default.createElement(_TextRenderer.default, props, children)));
};

describe('<TextRenderer />', function () {
  it('should render an TextRenderer with children', function () {
    var renderedComponent = renderComponent();
    expect(renderedComponent.contains(children)).toEqual(true);
  });
  it('should render an TextRenderer with strong tag', function () {
    var renderedComponent = renderComponentUsingTheme({
      semantic: 'strong'
    });
    expect(renderedComponent.find('Strong').length).toBe(1);
  });
  it('should render an TextRenderer with em tag', function () {
    var renderedComponent = renderComponentUsingTheme({
      semantic: 'em'
    });
    expect(renderedComponent.find('em').length).toBe(1);
  });
  it('should render an TextRenderer with span tag', function () {
    var renderedComponent = renderComponentUsingTheme();
    expect(renderedComponent.find('span').length).toBe(1);
  });
  it('should render an TextRenderer with em tag with size-inherit classname', function () {
    var renderedComponent = renderComponentUsingTheme({
      semantic: 'em',
      size: 'inherit'
    });
    expect(renderedComponent.find('em').hasClass('size-inherit')).toEqual(true);
  });
  it('should render an TextRenderer with em tag with size-small classname', function () {
    var renderedComponent = renderComponentUsingTheme({
      semantic: 'em',
      size: 'small'
    });
    expect(renderedComponent.find('em').hasClass('size-small')).toEqual(true);
  });
  it('should render an TextRenderer with em tag with size-base classname', function () {
    var renderedComponent = renderComponentUsingTheme({
      semantic: 'em',
      size: 'base'
    });
    expect(renderedComponent.find('em').hasClass('size-base')).toEqual(true);
  });
  it('should render an TextRenderer with em tag with size-text classname', function () {
    var renderedComponent = renderComponentUsingTheme({
      semantic: 'em',
      size: 'text'
    });
    expect(renderedComponent.find('em').hasClass('size-text')).toEqual(true);
  });
  it('should render an TextRenderer with em tag with color-base classname', function () {
    var renderedComponent = renderComponentUsingTheme({
      semantic: 'em',
      color: 'base'
    });
    expect(renderedComponent.find('em').hasClass('color-base')).toEqual(true);
  });
  it('should render an TextRenderer with em tag with color-light classname', function () {
    var renderedComponent = renderComponentUsingTheme({
      semantic: 'em',
      color: 'light'
    });
    expect(renderedComponent.find('em').hasClass('color-light')).toEqual(true);
  });
  it('should render an TextRenderer with em tag with color-light classname', function () {
    var renderedComponent = renderComponentUsingTheme({
      semantic: 'em',
      underlined: true
    });
    expect(renderedComponent.find('em').hasClass('underlined')).toEqual(true);
  });
});